@@ -1,9 +1,9 @@
-require "sqlite3"
 
+local sqlite3 = require("lsqlite3")
 
 local db = sqlite3.open_memory()
 
-db:set_trace_handler( function(sql)
+db:trace( function(ud, sql)
   print("Sqlite Trace:", sql)
 end )
 
